##  Subscription Mode
You can make the selection of a Subscription Role mandatory by choosing Required. Opting for Optional allows users to decide whether to select a Subscription Role or not. For more on Subscription Role, see [Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
![Choosing Subscription Mode](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274622427a4410148468bbffe9adfc69_LowRes.png)
Choosing Subscription Mode
**Caution**
if you set the subscription mode to required, ensure you have defined subscription roles for Fact Sheets. Otherwise, users won't be able to choose a role and they may subscribe to Fact Sheets without a subscription role.
